@@ -161,7 +161,7 @@ QAbstractButton *Window :: setIcon(int id)
 			}
 		else if(finished){
                         disconnect(bgroup, SIGNAL(buttonClicked(int)), this, SLOT(setIcon(int)));
-				int res = QMessageBox::warning(this, tr("Cat Application"),
+				int res = QMessageBox::warning(this, tr("Crazycat"),
                    			tr("Cat Won................\n"
                       			"Do you want to play a new game?"),
                    			QMessageBox::Yes | QMessageBox::No,
